<xsl:stylesheet version="2.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:c="http://cv.org"
                xmlns="http://www.w3.org/1999/xhtml">

  <xsl:template match="c:CV">
    <html xmlns="http://www.w3.org/1999/xhtml">
      <head>
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
        <meta name="robots" content="noindex, nofollow"/>
        <title>CV | <xsl:value-of select="c:Credentials/c:FullName"/></title>
        <xsl:call-template name="css"/>
      </head>
      <body>
        <xsl:apply-templates select="c:Credentials"/>
        <xsl:apply-templates select="c:Qualifications"/>
        <xsl:apply-templates select="c:Jobs"/>
        <xsl:apply-templates select="c:Volunteer"/>
        <xsl:apply-templates select="c:Education"/>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="c:Credentials">
    <h1><xsl:value-of select="c:FullName"/></h1>
    <div id="contact">
      <p><xsl:value-of select="c:Address"/></p>
      <p><xsl:value-of select="c:Phone"/></p>
      <p><a href="mailto:{c:Email}"><xsl:value-of select="c:Email"/></a></p>
      <xsl:if test="c:Website">
        <p><a href="http://{c:Website}"><xsl:value-of select="c:Website"/></a></p>
      </xsl:if>
      <p>Age: <xsl:value-of select="c:Age"/></p>
      <xsl:for-each select="c:Other/*">
        <p><xsl:value-of select="."/></p>
      </xsl:for-each>
    </div>
  </xsl:template>

  <xsl:template match="c:Qualifications">
    <h2>Summary of Qualifications</h2>
    <xsl:for-each select="c:Qualification">
      <xsl:call-template name="list-qualification"/>
    </xsl:for-each>
  </xsl:template>

  <xsl:template match="c:Jobs">
    <h2>Work Experience</h2>
    <xsl:apply-templates select="c:Job">
      <xsl:sort select="c:EndYear" data-type="text" order="descending"/>
      <xsl:sort select="c:StartYear" data-type="text" order="descending"/>
    </xsl:apply-templates>
  </xsl:template>

  <xsl:template match="c:Volunteer">
    <h2>Interests / Volunteer</h2>
    <xsl:apply-templates select="c:Interest">
      <xsl:sort select="c:EndYear" data-type="text" order="descending"/>
      <xsl:sort select="c:StartYear" data-type="text" order="descending"/>
    </xsl:apply-templates>
  </xsl:template>

  <xsl:template match="c:Education">
    <h2>Education</h2>
    <ul>
      <xsl:apply-templates select="c:Degree">
        <xsl:sort select="c:EndYear" data-type="text" order="descending"/>
        <xsl:sort select="c:StartYear" data-type="text" order="descending"/>
      </xsl:apply-templates>
    </ul>
  </xsl:template>

  <xsl:template name="list-qualification">
    <h3><xsl:value-of select="c:Name"/></h3>
    <ul>
      <xsl:for-each select="c:Experience/c:Item">
        <li><xsl:value-of select="."/></li>
      </xsl:for-each>
    </ul>
  </xsl:template>

  <xsl:template match="c:Job|c:Interest">
    <div class="entry">
      <span class="date"><xsl:value-of select="c:StartYear"
      /> &#187; <xsl:value-of select="c:EndYear"/></span>
      <h3><xsl:value-of select="c:JobTitle"/></h3>
      <address><xsl:value-of select="c:Company"/></address>
      <ul>
      <xsl:for-each select="c:Experience/c:Item">
        <li><xsl:value-of select="."/></li>
      </xsl:for-each>
      </ul>
      <xsl:if test="c:Description">
        <p><xsl:value-of select="c:Description"/></p>
      </xsl:if>
    </div>
  </xsl:template>

  <xsl:template match="c:Degree">
    <li><xsl:value-of select="c:Name"
    />, <xsl:value-of select="c:Institution/c:Name"
    />, <xsl:value-of select="c:Institution/c:Province"
    /><span class="date"><xsl:value-of select="c:StartYear"
    /> &#187; <xsl:value-of select="c:EndYear"/></span></li>
  </xsl:template>

  <xsl:template name="css">
    <style type="text/css" media="all">
      html {
        background-color:#EEE;
        padding:0 1em;
      }
      body {
        background-color:#FFF;
        font-family:"Trebuchet MS",Helvetica,Arial;
        padding:1em;
        border:solid #AAA;
        border-width:1px 3px 3px 1px;
        margin:1em auto;
        max-width:50em;
      }
      #contact p { margin:0em 0em 0em 0em; }
      .date {
        float:right;
        font-size:.8em;
        text-align:right;
      }
      .entry p { margin-left:1.5em; }
      address {
        font-style:italic;
        color:#333;
        font-size:.9em;
      }
      h1 {
        font-size:1.5em;
        font-family:Helvetica,Verdana,Arial,sans-serif;
      }
      h2 {
        clear:both;
        font-size:1.4em;
        font-weight:bold;
        margin-top:2em;
        font-variant:small-caps;
        padding-left:.25em;
        background-color:#EEE;
        border-bottom:1px solid #999;
        letter-spacing:.06em;
      }
      h3 {margin: 1em 0 0 0;}
    </style>
    <style type="text/css" media="print">
      body {
        background-color:#FFF;
        border-width:0 0 0 0;
        margin:0;
        width:100%
      }
    </style>
  </xsl:template>

</xsl:stylesheet>